@@ -1,5 +1,4 @@
-name = "zeus-mcmc"
-__version__ = "1.2.0"
+__version__ = "1.2.1"
 __url__ = "https://zeus-mcmc.readthedocs.io"
 __author__ = "Minas Karamanis"
 __email__ = "minaskar@gmail.com"
@@ -7,4 +6,7 @@ __license__ = "GPL-3.0"
 __description__ = "Lightning Fast MCMC"
 
 
-from .zeus import *
\ No newline at end of file
+from .ensemble import *
+from .diagnostics import GelmanRubin, Geweke
+from .parallel import ChainManager
+from .autocorr import AutoCorrTime
\ No newline at end of file
